==> 0.0.6-prerelease.tar.gz: lib/src/videos/widgets/url-our-path/CustomFLickFullScreen.dart <==
part of modern_form_videos;

class CustomFLickFullScreen extends StatefulWidget {
  final FlickManager flickManager;
  final Widget Function(double s) shareIcon;

  const CustomFLickFullScreen({Key key, this.flickManager, this.shareIcon})
      : super(key: key);

  @override
  _CustomFLickFullScreenState createState() => _CustomFLickFullScreenState();
}

class _CustomFLickFullScreenState extends State<CustomFLickFullScreen> {
  @override
  void initState() {
    SystemChrome.setPreferredOrientations([
      DeviceOrientation.landscapeLeft,
      // DeviceOrientation.landscapeRight,
      // DeviceOrientation.portraitDown,
      // DeviceOrientation.portraitUp,
    ]);
    super.initState();
  }

  @override
  void dispose() {
    // widget?.flickManager?.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Material(
      child: FlickVideoPlayer(
        flickManager: widget.flickManager,
        flickVideoWithControls: FlickVideoWithControls(
          videoFit: BoxFit.fill,
          controls: Stack(
            children: [
              CustomFlickPortraitControls(
                flickManager: widget?.flickManager,
                fontSize: 14,
                iconSize: 30,
                progressBarSettings: FlickProgressBarSettings(
                  height: 5,
                ),
                toggleFullscreen: () {
                  Navigator.pop(context);
                },
              ),
              Padding(
                padding: EdgeInsets.only(top: ScreenUtil().setHeight(20)),
                child: widget.shareIcon(18),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> 0.1.29-prerelease.tar.gz: lib/src/videos/widgets/url-our-path/CustomFLickFullScreen.dart <==
part of modern_form_videos;

class CustomFLickFullScreen extends StatefulWidget {
  final FlickManager flickManager;
  final Widget Function(double s) shareIcon;

  const CustomFLickFullScreen({Key key, this.flickManager, this.shareIcon})
      : super(key: key);

  @override
  _CustomFLickFullScreenState createState() => _CustomFLickFullScreenState();
}

class _CustomFLickFullScreenState extends State<CustomFLickFullScreen> {
  @override
  void initState() {
    SystemChrome.setPreferredOrientations([
      DeviceOrientation.landscapeLeft,
      // DeviceOrientation.landscapeRight,
      // DeviceOrientation.portraitDown,
      // DeviceOrientation.portraitUp,
    ]);
    super.initState();
  }

  @override
  void dispose() {
    // widget?.flickManager?.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Material(
      child: FlickVideoPlayer(
        flickManager: widget.flickManager,
        flickVideoWithControls: FlickVideoWithControls(
          videoFit: BoxFit.fill,
          controls: Stack(
            children: [
              CustomFlickPortraitControls(
                flickManager: widget?.flickManager,
                fontSize: 14,
                iconSize: 30,
                progressBarSettings: FlickProgressBarSettings(
                  height: 5,
                ),
                toggleFullscreen: () {
                  // Navigator.pop(context);
                  ModernFormNavigation.pop();
                },
              ),
              Padding(
                padding: EdgeInsets.only(top: ScreenUtil().setHeight(20)),
                child: widget.shareIcon(18),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
